@@ -549,7 +549,7 @@ public class Main implements AntMain {
          * to help or not, so we simply look for the equals sign.
          */
         final String arg = args[argPos];
-        String name = arg.substring(2, arg.length());
+        String name = arg.substring(2);
         String value;
         final int posEq = name.indexOf('=');
         if (posEq > 0) {
@@ -637,15 +637,11 @@ public class Main implements AntMain {
     private void loadPropertyFiles() {
         for (final String filename : propertyFiles) {
             final Properties props = new Properties();
-            InputStream fis = null;
-            try {
-                fis = Files.newInputStream(Paths.get(filename));
+            try (InputStream fis = Files.newInputStream(Paths.get(filename))) {
                 props.load(fis);
             } catch (final IOException e) {
                 System.out.println("Could not load property file "
                                    + filename + ": " + e.getMessage());
-            } finally {
-                FileUtils.close(fis);
             }
 
             // ensure that -D properties take precedence
@@ -900,7 +896,7 @@ public class Main implements AntMain {
         // Setting it here allows top-level tasks to access the
         // property.
         project.setUserProperty(MagicNames.PROJECT_INVOKED_TARGETS,
-                targets.stream().collect(Collectors.joining(",")));
+                String.join(",", targets));
     }
 
     /**
@@ -1016,10 +1012,10 @@ public class Main implements AntMain {
         System.out.println("  -inputhandler <class>  the class which will handle input requests");
         System.out.println("  -find <file>           (s)earch for buildfile towards the root of");
         System.out.println("    -s  <file>           the filesystem and use it");
-        System.out.println("  -nice  number          A niceness value for the main thread:"
-                + "                         1 (lowest) to 10 (highest); 5 is the default");
-        System.out.println("  -nouserlib             Run ant without using the jar files from"
-                + "                         ${user.home}/.ant/lib");
+        System.out.println("  -nice  number          A niceness value for the main thread:");
+        System.out.println("                         1 (lowest) to 10 (highest); 5 is the default");
+        System.out.println("  -nouserlib             Run ant without using the jar files from");
+        System.out.println("                         ${user.home}/.ant/lib");
         System.out.println("  -noclasspath           Run ant without using CLASSPATH");
         System.out.println("  -autoproxy             Java1.5+: use the OS proxy settings");
         System.out.println("  -main <class>          override Ant's normal entry point");
