@@ -23,8 +23,9 @@ import java.io.InputStreamReader;
 import java.lang.reflect.Constructor;
 import java.net.URL;
 import java.net.URLConnection;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
-import java.util.Enumeration;
+import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
 import java.util.stream.Stream;
@@ -32,6 +33,7 @@ import java.util.stream.Stream;
 import org.apache.tools.ant.helper.ProjectHelper2;
 import org.apache.tools.ant.types.Resource;
 import org.apache.tools.ant.util.LoaderUtils;
+import org.apache.tools.ant.util.StreamUtils;
 
 /**
  * Repository of {@link ProjectHelper} found in the classpath or via
@@ -77,31 +79,24 @@ public class ProjectHelperRepository {
 
     private void collectProjectHelpers() {
         // First, try the system property
-        Constructor<? extends ProjectHelper> projectHelper = getProjectHelperBySystemProperty();
-        registerProjectHelper(projectHelper);
+        registerProjectHelper(getProjectHelperBySystemProperty());
 
         // A JDK1.3 'service' (like in JAXP). That will plug a helper
         // automatically if in CLASSPATH, with the right META-INF/services.
         try {
             ClassLoader classLoader = LoaderUtils.getContextClassLoader();
             if (classLoader != null) {
-                Enumeration<URL> resources =
-                    classLoader.getResources(ProjectHelper.SERVICE_ID);
-                while (resources.hasMoreElements()) {
-                    URL resource = resources.nextElement();
+                for (URL resource : Collections.list(classLoader.getResources(ProjectHelper.SERVICE_ID))) {
                     URLConnection conn = resource.openConnection();
                     conn.setUseCaches(false);
-                    projectHelper =
-                        getProjectHelperByService(conn.getInputStream());
-                    registerProjectHelper(projectHelper);
+                    registerProjectHelper(getProjectHelperByService(conn.getInputStream()));
                 }
             }
 
             InputStream systemResource =
                 ClassLoader.getSystemResourceAsStream(ProjectHelper.SERVICE_ID);
             if (systemResource != null) {
-                projectHelper = getProjectHelperByService(systemResource);
-                registerProjectHelper(projectHelper);
+                registerProjectHelper(getProjectHelperByService(systemResource));
             }
         } catch (Exception e) {
             System.err.println("Unable to load ProjectHelper from service "
@@ -186,18 +181,12 @@ public class ProjectHelperRepository {
         try {
             // This code is needed by EBCDIC and other strange systems.
             // It's a fix for bugs reported in xerces
-            InputStreamReader isr;
-            try {
-                isr = new InputStreamReader(is, "UTF-8");
-            } catch (java.io.UnsupportedEncodingException e) {
-                isr = new InputStreamReader(is);
-            }
-            BufferedReader rd = new BufferedReader(isr);
-
+            BufferedReader rd = new BufferedReader(new InputStreamReader(is,
+                    StandardCharsets.UTF_8));
             String helperClassName = rd.readLine();
             rd.close();
 
-            if (helperClassName != null && !"".equals(helperClassName)) {
+            if (helperClassName != null && !helperClassName.isEmpty()) {
                 return getHelperConstructor(helperClassName);
             }
         } catch (Exception e) {
@@ -253,20 +242,19 @@ public class ProjectHelperRepository {
      * @return the first ProjectHelper that fit the requirement (never <code>null</code>).
      */
     public ProjectHelper getProjectHelperForBuildFile(Resource buildFile) throws BuildException {
-        for (Iterator<ProjectHelper> it = getHelpers(); it.hasNext();) {
-            ProjectHelper helper = it.next();
-            if (helper.canParseBuildFile(buildFile)) {
-                if (DEBUG) {
-                    System.out.println("ProjectHelper "
-                                       + helper.getClass().getName()
-                                       + " selected for the build file "
-                                       + buildFile);
-                }
-                return helper;
-            }
+        ProjectHelper ph = StreamUtils.iteratorAsStream(getHelpers())
+                .filter(helper -> helper.canParseBuildFile(buildFile))
+                .findFirst().orElse(null);
+
+        if (ph == null) {
+            throw new BuildException("BUG: at least the ProjectHelper2 should "
+                    + "have supported the file " + buildFile);
         }
-        throw new BuildException("BUG: at least the ProjectHelper2 should "
-                                   + "have supported the file " + buildFile);
+        if (DEBUG) {
+            System.out.println("ProjectHelper " + ph.getClass().getName()
+                    + " selected for the build file " + buildFile);
+        }
+        return ph;
     }
 
     /**
@@ -277,20 +265,19 @@ public class ProjectHelperRepository {
      * @return the first ProjectHelper that fit the requirement (never <code>null</code>).
      */
     public ProjectHelper getProjectHelperForAntlib(Resource antlib) throws BuildException {
-        for (Iterator<ProjectHelper> it = getHelpers(); it.hasNext();) {
-            ProjectHelper helper = it.next();
-            if (helper.canParseAntlibDescriptor(antlib)) {
-                if (DEBUG) {
-                    System.out.println("ProjectHelper "
-                                       + helper.getClass().getName()
-                                       + " selected for the antlib "
-                                       + antlib);
-                }
-                return helper;
-            }
+        ProjectHelper ph = StreamUtils.iteratorAsStream(getHelpers())
+                .filter(helper -> helper.canParseAntlibDescriptor(antlib))
+                .findFirst().orElse(null);
+
+        if (ph == null) {
+            throw new BuildException("BUG: at least the ProjectHelper2 should "
+                    + "have supported the file " + antlib);
         }
-        throw new BuildException("BUG: at least the ProjectHelper2 should "
-                                   + "have supported the file " + antlib);
+        if (DEBUG) {
+            System.out.println("ProjectHelper " + ph.getClass().getName()
+                    + " selected for the antlib " + antlib);
+        }
+        return ph;
     }
 
     /**
