@@ -29,6 +29,7 @@ import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -60,7 +61,6 @@ import org.apache.tools.ant.types.ResourceCollection;
 import org.apache.tools.ant.types.resources.FileProvider;
 import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.JavaEnvUtils;
-import org.apache.tools.ant.util.StringUtils;
 
 /**
  * Generates Javadoc documentation for a collection
@@ -451,11 +451,14 @@ public class Javadoc extends Task {
     private final List<SourceFile> sourceFiles = new Vector<>();
     private final List<PackageName> packageNames = new Vector<>();
     private final List<PackageName> excludePackageNames = new Vector<>(1);
+    private final List<PackageName> moduleNames = new ArrayList<>();
     private boolean author = true;
     private boolean version = true;
     private DocletInfo doclet = null;
     private Path classpath = null;
     private Path bootclasspath = null;
+    private Path modulePath = null;
+    private Path moduleSourcePath = null;
     private String group = null;
     private String packageList = null;
     private final List<LinkArgument> links = new Vector<>();
@@ -566,6 +569,88 @@ public class Javadoc extends Task {
         createSourcepath().setRefid(r);
     }
 
+    /**
+     * Specify where to find modules
+     *
+     * @param mp a Path instance containing the modules.
+     *
+     * @since Ant 1.10.6
+     */
+    public void setModulePath(final Path mp) {
+        if (modulePath == null) {
+            modulePath = mp;
+        } else {
+            modulePath.append(mp);
+        }
+    }
+
+    /**
+     * Create a path to be configured with the locations of the module
+     * files.
+     *
+     * @return a new Path instance to be configured by the Ant core.
+     *
+     * @since Ant 1.10.6
+     */
+    public Path createModulePath() {
+        if (modulePath == null) {
+            modulePath = new Path(getProject());
+        }
+        return modulePath.createPath();
+    }
+
+    /**
+     * Adds a reference to a path defined elsewhere that defines the module path.
+     *
+     * @param r the reference containing the module path definition.
+     *
+     * @since Ant 1.10.6
+     */
+    public void setModulePathref(final Reference r) {
+        createModulePath().setRefid(r);
+    }
+
+    /**
+     * Specify where to find sources for modules
+     *
+     * @param mp a Path instance containing the sources for modules.
+     *
+     * @since Ant 1.10.6
+     */
+    public void setModuleSourcePath(final Path mp) {
+        if (moduleSourcePath == null) {
+            moduleSourcePath = mp;
+        } else {
+            moduleSourcePath.append(mp);
+        }
+    }
+
+    /**
+     * Create a path to be configured with the locations of the module
+     * source files.
+     *
+     * @return a new Path instance to be configured by the Ant core.
+     *
+     * @since Ant 1.10.6
+     */
+    public Path createModuleSourcePath() {
+        if (moduleSourcePath == null) {
+            moduleSourcePath = new Path(getProject());
+        }
+        return moduleSourcePath.createPath();
+    }
+
+    /**
+     * Adds a reference to a path defined elsewhere that defines the module source path.
+     *
+     * @param r the reference containing the module source path definition.
+     *
+     * @since Ant 1.10.6
+     */
+    public void setModuleSourcePathref(final Reference r) {
+        createModuleSourcePath().setRefid(r);
+    }
+
     /**
      * Set the directory where the Javadoc output will be generated.
      *
@@ -619,6 +704,21 @@ public class Javadoc extends Task {
         }
     }
 
+    /**
+     * Set the module names to be processed.
+     *
+     * @param modules a comma separated list of module names
+     *
+     * @since Ant 1.10.6
+     */
+    public void setModulenames(final String modules) {
+        for (String m : modules.split(",")) {
+            final PackageName mn = new PackageName();
+            mn.setName(m);
+            addModule(mn);
+        }
+    }
+
     /**
      * Add a single package to be processed.
      *
@@ -631,6 +731,17 @@ public class Javadoc extends Task {
         packageNames.add(pn);
     }
 
+    /**
+     * Add a single module to be processed.
+     *
+     * @param mn the module name
+     *
+     * @since Ant 1.10.6
+     */
+    public void addModule(final PackageName mn) {
+        moduleNames.add(mn);
+    }
+
     /**
      * Set the list of packages to be excluded.
      *
@@ -1055,7 +1166,7 @@ public class Javadoc extends Task {
         final String linkOfflineError = "The linkoffline attribute must include"
             + " a URL and a package-list file location separated by a"
             + " space";
-        if (src.trim().length() == 0) {
+        if (src.trim().isEmpty()) {
             throw new BuildException(linkOfflineError);
         }
         final StringTokenizer tok = new StringTokenizer(src, " ", false);
@@ -1737,6 +1848,7 @@ public class Javadoc extends Task {
         doGroup(toExecute);    // group attribute
         doGroups(toExecute);  // groups attribute
         doDocFilesSubDirs(toExecute); // docfilessubdir attribute
+        doModuleArguments(toExecute);
 
         doJava14(toExecute);
         if (breakiterator && (doclet == null || JAVADOC_5)) {
@@ -1852,9 +1964,9 @@ public class Javadoc extends Task {
     private void checkPackagesToDoc(
         final List<String> packagesToDoc, final List<SourceFile> sourceFilesToDoc) {
         if (packageList == null && packagesToDoc.isEmpty()
-            && sourceFilesToDoc.isEmpty()) {
-            throw new BuildException(
-                "No source files and no packages have been specified.");
+            && sourceFilesToDoc.isEmpty() && moduleNames.isEmpty()) {
+            throw new BuildException("No source files, no packages and no modules have "
+                                     + "been specified.");
         }
     }
 
@@ -1909,31 +2021,24 @@ public class Javadoc extends Task {
     private void doDoclet(final Commandline toExecute) {
         if (doclet != null) {
             if (doclet.getName() == null) {
-                throw new BuildException("The doclet name must be specified.",
-                    getLocation());
+                throw new BuildException("The doclet name must be specified.", getLocation());
             }
             toExecute.createArgument().setValue("-doclet");
             toExecute.createArgument().setValue(doclet.getName());
             if (doclet.getPath() != null) {
-                final Path docletPath
-                    = doclet.getPath().concatSystemClasspath("ignore");
+                final Path docletPath = doclet.getPath().concatSystemClasspath("ignore");
                 if (docletPath.size() != 0) {
                     toExecute.createArgument().setValue("-docletpath");
                     toExecute.createArgument().setPath(docletPath);
                 }
             }
-            for (final Enumeration<DocletParam> e = doclet.getParams();
-                 e.hasMoreElements();) {
-                final DocletParam param = e.nextElement();
+            for (final DocletParam param : Collections.list(doclet.getParams())) {
                 if (param.getName() == null) {
-                    throw new BuildException(
-                        "Doclet parameters must have a name");
+                    throw new BuildException("Doclet parameters must have a name");
                 }
-
                 toExecute.createArgument().setValue(param.getName());
                 if (param.getValue() != null) {
-                    toExecute.createArgument()
-                        .setValue(param.getValue());
+                    toExecute.createArgument().setValue(param.getValue());
                 }
             }
         }
@@ -2123,23 +2228,17 @@ public class Javadoc extends Task {
                     // -tag arguments.
                     final DirectoryScanner tagDefScanner =
                         ta.getDirectoryScanner(getProject());
-                    final String[] files = tagDefScanner.getIncludedFiles();
-                    for (String file : files) {
+                    for (String file : tagDefScanner.getIncludedFiles()) {
                         final File tagDefFile = new File(tagDir, file);
-                        try (final BufferedReader in =
-                            new BufferedReader(new FileReader(tagDefFile))) {
-                            String line;
-                            while ((line = in.readLine()) != null) {
-                                toExecute.createArgument()
-                                    .setValue("-tag");
-                                toExecute.createArgument()
-                                    .setValue(line);
-                            }
+                        try (final BufferedReader in = new BufferedReader(
+                                new FileReader(tagDefFile))) {
+                            in.lines().forEach(line -> {
+                                toExecute.createArgument().setValue("-tag");
+                                toExecute.createArgument().setValue(line);
+                            });
                         } catch (final IOException ioe) {
-                            throw new BuildException(
-                                "Couldn't read tag file from "
-                                    + tagDefFile.getAbsolutePath(),
-                                ioe);
+                            throw new BuildException("Couldn't read tag file from "
+                                    + tagDefFile.getAbsolutePath(), ioe);
                         }
                     }
                 }
@@ -2179,8 +2278,7 @@ public class Javadoc extends Task {
     private void doDocFilesSubDirs(final Commandline toExecute) {
         if (docFilesSubDirs) {
             toExecute.createArgument().setValue("-docfilessubdirs");
-            if (!(excludeDocFilesSubDir == null
-                || excludeDocFilesSubDir.trim().isEmpty())) {
+            if (excludeDocFilesSubDir != null && !excludeDocFilesSubDir.trim().isEmpty()) {
                 toExecute.createArgument().setValue("-excludedocfilessubdir");
                 toExecute.createArgument().setValue(excludeDocFilesSubDir);
             }
@@ -2209,7 +2307,7 @@ public class Javadoc extends Task {
             if (useExternalFile) {
                 // TODO what is the following doing?
                 //     should it run if !javadoc4 && executable != null?
-                if (sourceFileName.indexOf(' ') > -1) {
+                if (sourceFileName.contains(" ")) {
                     String name = sourceFileName;
                     if (File.separatorChar == '\\') {
                         name = sourceFileName.replace(File.separatorChar, '/');
@@ -2233,20 +2331,18 @@ public class Javadoc extends Task {
      */
     private String quoteString(final String str) {
         if (!containsWhitespace(str)
-            && str.indexOf('\'') == -1
-            && str.indexOf('"') == -1) {
+            && !str.contains("'") && !str.contains("\"")) {
             return str;
         }
-        if (str.indexOf('\'') == -1) {
+        if (!str.contains("'")) {
             return quoteString(str, '\'');
         }
         return quoteString(str, '"');
     }
 
     private boolean containsWhitespace(final String s) {
-        final int len = s.length();
-        for (int i = 0; i < len; i++) {
-            if (Character.isWhitespace(s.charAt(i))) {
+        for (char c : s.toCharArray()) {
+            if (Character.isWhitespace(c)) {
                 return true;
             }
         }
@@ -2256,10 +2352,8 @@ public class Javadoc extends Task {
     private String quoteString(final String str, final char delim) {
         final StringBuilder buf = new StringBuilder(str.length() * 2);
         buf.append(delim);
-        final int len = str.length();
         boolean lastCharWasCR = false;
-        for (int i = 0; i < len; i++) {
-            final char c = str.charAt(i);
+        for (final char c : str.toCharArray()) {
             if (c == delim) { // can't put the non-constant delim into a case
                 buf.append('\\').append(c);
                 lastCharWasCR = false;
@@ -2376,24 +2470,23 @@ public class Javadoc extends Task {
             final File baseDir = ds.getDir(getProject());
             log("scanning " + baseDir + " for packages.", Project.MSG_DEBUG);
             final DirectoryScanner dsc = ds.getDirectoryScanner(getProject());
-            final String[] dirs = dsc.getIncludedDirectories();
             boolean containsPackages = false;
-            for (int i = 0; i < dirs.length; i++) {
+            for (String dir : dsc.getIncludedDirectories()) {
                 // are there any java files in this directory?
-                final File pd = new File(baseDir, dirs[i]);
-                final String[] files = pd.list((dir1,
+                final File pd = new File(baseDir, dir);
+                final String[] files = pd.list((directory,
                     name) -> name.endsWith(".java") || (includeNoSourcePackages
                         && name.equals("package.html")));
 
                 if (files.length > 0) {
-                    if ("".equals(dirs[i])) {
+                    if (dir.isEmpty()) {
                         log(baseDir
                             + " contains source files in the default package, you must specify them as source files not packages.",
                             Project.MSG_WARN);
                     } else {
                         containsPackages = true;
                         final String packageName =
-                            dirs[i].replace(File.separatorChar, '.');
+                                dir.replace(File.separatorChar, '.');
                         if (!addedPackages.contains(packageName)) {
                             addedPackages.add(packageName);
                             pn.add(packageName);
@@ -2431,7 +2524,7 @@ public class Javadoc extends Task {
         try {
             fixData =
                 fixLineFeeds(FileUtils
-                             .readFully(new InputStreamReader(in, "US-ASCII")))
+                             .readFully(new InputStreamReader(in, StandardCharsets.US_ASCII)))
                 .trim();
         } finally {
             FileUtils.close(in);
@@ -2468,7 +2561,7 @@ public class Javadoc extends Task {
 
         // check if file may be vulnerable because it was not
         // patched with "validURL(url)":
-        if (fileContents.indexOf("function validURL(url) {") < 0) {
+        if (!fileContents.contains("function validURL(url) {")) {
             // we need to patch the file!
             final String patchedFileContents = patchContent(fileContents, fixData);
             if (!patchedFileContents.equals(fileContents)) {
@@ -2485,7 +2578,7 @@ public class Javadoc extends Task {
 
     private String fixLineFeeds(final String orig) {
         return orig.replace("\r\n", "\n")
-            .replace("\n", StringUtils.LINE_SEP);
+            .replace("\n", System.lineSeparator());
     }
 
     private String patchContent(final String fileContents, final String fixData) {
@@ -2498,6 +2591,23 @@ public class Javadoc extends Task {
         return fileContents;
     }
 
+    private void doModuleArguments(Commandline toExecute) {
+        if (!moduleNames.isEmpty()) {
+            toExecute.createArgument().setValue("--module");
+            toExecute.createArgument()
+                .setValue(moduleNames.stream().map(PackageName::getName)
+                          .collect(Collectors.joining(",")));
+        }
+        if (modulePath != null) {
+            toExecute.createArgument().setValue("--module-path");
+            toExecute.createArgument().setPath(modulePath);
+        }
+        if (moduleSourcePath != null) {
+            toExecute.createArgument().setValue("--module-source-path");
+            toExecute.createArgument().setPath(moduleSourcePath);
+        }
+    }
+
     private class JavadocOutputStream extends LogOutputStream {
         JavadocOutputStream(final int level) {
             super(Javadoc.this, level);
