@@ -25,7 +25,8 @@ import java.io.InputStreamReader;
 import java.io.PrintWriter;
 import java.io.Reader;
 import java.io.StringWriter;
-import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.LinkedHashMap;
@@ -34,10 +35,8 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Vector;
-import java.util.stream.Collectors;
 
 import org.apache.tools.ant.BuildException;
-import org.apache.tools.ant.util.FileUtils;
 import org.apache.tools.ant.util.StreamUtils;
 
 /**
@@ -92,8 +91,11 @@ public class Manifest {
     public static final String ERROR_FROM_FORBIDDEN = "Manifest attributes should not start "
                         + "with \"" + ATTRIBUTE_FROM + "\" in \"";
 
+    /** Charset to be used for JAR files. */
+    public static final Charset JAR_CHARSET = StandardCharsets.UTF_8;
     /** Encoding to be used for JAR files. */
-    public static final String JAR_ENCODING = "UTF-8";
+    @Deprecated
+    public static final String JAR_ENCODING = JAR_CHARSET.name();
 
     private static final String ATTRIBUTE_MANIFEST_VERSION_LC =
         ATTRIBUTE_MANIFEST_VERSION.toLowerCase(Locale.ENGLISH);
@@ -263,7 +265,7 @@ public class Manifest {
          */
         public String getValue() {
             return values.isEmpty() ? null
-                : values.stream().collect(Collectors.joining(" "));
+                : String.join(" ", values);
         }
 
         /**
@@ -343,7 +345,7 @@ public class Manifest {
         private void writeValue(PrintWriter writer, String value)
              throws IOException {
             String line;
-            int nameLength = name.getBytes(JAR_ENCODING).length;
+            int nameLength = name.getBytes(JAR_CHARSET).length;
             if (nameLength > MAX_NAME_VALUE_LENGTH) {
                 if (nameLength > MAX_NAME_LENGTH) {
                     throw new IOException("Unable to write manifest line "
@@ -354,14 +356,14 @@ public class Manifest {
             } else {
                 line = name + ": " + value;
             }
-            while (line.getBytes(JAR_ENCODING).length > MAX_SECTION_LENGTH) {
+            while (line.getBytes(JAR_CHARSET).length > MAX_SECTION_LENGTH) {
                 // try to find a MAX_LINE_LENGTH byte section
                 int breakIndex = MAX_SECTION_LENGTH;
                 if (breakIndex >= line.length()) {
                     breakIndex = line.length() - 1;
                 }
                 String section = line.substring(0, breakIndex);
-                while (section.getBytes(JAR_ENCODING).length > MAX_SECTION_LENGTH
+                while (section.getBytes(JAR_CHARSET).length > MAX_SECTION_LENGTH
                      && breakIndex > 0) {
                     breakIndex--;
                     section = line.substring(0, breakIndex);
@@ -751,35 +753,25 @@ public class Manifest {
      *            default manifest
      */
     public static Manifest getDefaultManifest() throws BuildException {
-        InputStreamReader insr = null;
         String defManifest = "/org/apache/tools/ant/defaultManifest.mf";
         try (InputStream in = Manifest.class.getResourceAsStream(defManifest)) {
             if (in == null) {
                 throw new BuildException("Could not find default manifest: %s",
                     defManifest);
             }
-            try {
-                insr = new InputStreamReader(in, "UTF-8");
-                Manifest defaultManifest = new Manifest(insr);
-                String version = System.getProperty("java.runtime.version");
-                if (version == null) {
-                    version = System.getProperty("java.vm.version");
-                }
-                Attribute createdBy = new Attribute("Created-By",
-                    version + " ("
-                    + System.getProperty("java.vm.vendor") + ")");
-                defaultManifest.getMainSection().storeAttribute(createdBy);
-                return defaultManifest;
-            } catch (UnsupportedEncodingException e) {
-                insr = new InputStreamReader(in);
-                return new Manifest(insr);
+            Manifest defaultManifest = new Manifest(new InputStreamReader(in, JAR_CHARSET));
+            String version = System.getProperty("java.runtime.version");
+            if (version == null) {
+                version = System.getProperty("java.vm.version");
             }
+            Attribute createdBy = new Attribute("Created-By", version
+                    + " (" + System.getProperty("java.vm.vendor") + ")");
+            defaultManifest.getMainSection().storeAttribute(createdBy);
+            return defaultManifest;
         } catch (ManifestException e) {
             throw new BuildException("Default manifest is invalid !!", e);
         } catch (IOException e) {
             throw new BuildException("Unable to read default manifest", e);
-        } finally {
-            FileUtils.close(insr);
         }
     }
 
