@@ -36,7 +36,7 @@ import org.apache.tools.ant.util.ResourceUtils;
 /**
  * Signs JAR or ZIP files with the javasign command line tool. The tool detailed
  * dependency checking: files are only signed if they are not signed. The
- * <tt>signjar</tt> attribute can point to the file to generate; if this file
+ * <code>signjar</code> attribute can point to the file to generate; if this file
  * exists then its modification date is used as a cue as to whether to resign
  * any JAR file.
  *
@@ -52,6 +52,38 @@ public class SignJar extends AbstractJarSignerTask {
 
     private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
 
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_TODIR_AND_SIGNEDJAR
+            = "'destdir' and 'signedjar' cannot both be set";
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_TOO_MANY_MAPPERS = "Too many mappers";
+    /**
+     * error string for unit test verification {@value}
+     */
+    public static final String ERROR_SIGNEDJAR_AND_PATHS
+        = "You cannot specify the signed JAR when using paths or filesets";
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_BAD_MAP = "Cannot map source file to anything sensible: ";
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_MAPPER_WITHOUT_DEST
+        = "The destDir attribute is required if a mapper is set";
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_NO_ALIAS = "alias attribute must be set";
+    /**
+     * error string for unit test verification: {@value}
+     */
+    public static final String ERROR_NO_STOREPASS = "storepass attribute must be set";
+
     /**
      * name to a signature file
      */
@@ -129,36 +161,10 @@ public class SignJar extends AbstractJarSignerTask {
     private String digestAlg;
 
     /**
-     * error string for unit test verification: {@value}
+     * tsa digest algorithm
      */
-    public static final String ERROR_TODIR_AND_SIGNEDJAR
-            = "'destdir' and 'signedjar' cannot both be set";
-    /**
-     * error string for unit test verification: {@value}
-     */
-    public static final String ERROR_TOO_MANY_MAPPERS = "Too many mappers";
-    /**
-     * error string for unit test verification {@value}
-     */
-    public static final String ERROR_SIGNEDJAR_AND_PATHS
-        = "You cannot specify the signed JAR when using paths or filesets";
-    /**
-     * error string for unit test verification: {@value}
-     */
-    public static final String ERROR_BAD_MAP = "Cannot map source file to anything sensible: ";
-    /**
-     * error string for unit test verification: {@value}
-     */
-    public static final String ERROR_MAPPER_WITHOUT_DEST
-        = "The destDir attribute is required if a mapper is set";
-    /**
-     * error string for unit test verification: {@value}
-     */
-    public static final String ERROR_NO_ALIAS = "alias attribute must be set";
-    /**
-     * error string for unit test verification: {@value}
-     */
-    public static final String ERROR_NO_STOREPASS = "storepass attribute must be set";
+    private String tsaDigestAlg;
+
     // CheckStyle:VisibilityModifier ON
 
     /**
@@ -315,6 +321,7 @@ public class SignJar extends AbstractJarSignerTask {
 
     /**
      * Whether to force signing of a jar even it is already signed.
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setForce(boolean b) {
@@ -324,6 +331,7 @@ public class SignJar extends AbstractJarSignerTask {
     /**
      * Should the task force signing of a jar even it is already
      * signed?
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean isForce() {
@@ -341,6 +349,8 @@ public class SignJar extends AbstractJarSignerTask {
 
     /**
      * Signature Algorithm; optional
+     *
+     * @return String
      */
     public String getSigAlg() {
         return sigAlg;
@@ -357,11 +367,33 @@ public class SignJar extends AbstractJarSignerTask {
 
     /**
      * Digest Algorithm; optional
+     *
+     * @return String
      */
     public String getDigestAlg() {
         return digestAlg;
     }
 
+    /**
+     * TSA Digest Algorithm; optional
+     *
+     * @param digestAlg the tsa digest algorithm
+     * @since Ant 1.10.2
+     */
+    public void setTSADigestAlg(String digestAlg) {
+        this.tsaDigestAlg = digestAlg;
+    }
+
+    /**
+     * TSA Digest Algorithm; optional
+     *
+     * @return String
+     * @since Ant 1.10.2
+     */
+    public String getTSADigestAlg() {
+        return tsaDigestAlg;
+    }
+
     /**
      * sign the jar(s)
      *
@@ -418,14 +450,7 @@ public class SignJar extends AbstractJarSignerTask {
 
             Path sources = createUnifiedSourcePath();
             //set up our mapping policy
-            FileNameMapper destMapper;
-            if (hasMapper) {
-                destMapper = mapper;
-            } else {
-                //no mapper? use the identity policy
-                destMapper = new IdentityMapper();
-            }
-
+            FileNameMapper destMapper = hasMapper ? mapper : new IdentityMapper();
 
             //at this point the paths are set up with lists of files,
             //and the mapper is ready to map from source dirs to dest files
@@ -461,7 +486,7 @@ public class SignJar extends AbstractJarSignerTask {
      *
      * @param jarSource source to sign
      * @param jarTarget target; may be null
-     * @throws BuildException
+     * @throws BuildException if something goes wrong
      */
     private void signOneJar(File jarSource, File jarTarget)
         throws BuildException {
@@ -564,6 +589,11 @@ public class SignJar extends AbstractJarSignerTask {
                 addProxyFor(cmd, "http");
             }
         }
+
+        if (tsaDigestAlg != null) {
+            addValue(cmd, "-tsadigestalg");
+            addValue(cmd, tsaDigestAlg);
+        }
     }
 
     /**
