@@ -244,11 +244,7 @@ public class FTP extends Task implements FTPTaskConfig {
          */
         @Override
         public String getParent() {
-            StringBuilder result = new StringBuilder();
-            for (int i = 0; i < parts.length - 1; i++) {
-                result.append(File.separatorChar).append(parts[i]);
-            }
-            return result.toString();
+            return File.separator + String.join(File.separator, parts);
         }
 
 
@@ -1290,7 +1286,7 @@ public class FTP extends Task implements FTPTaskConfig {
 
 
     /**
-     * A synonym for <tt>depends</tt>. Set to true to transmit only new
+     * A synonym for <code>depends</code>. Set to true to transmit only new
      * or changed files.
      *
      * See the related attributes timediffmillis and timediffauto.
