@@ -124,7 +124,7 @@ public class XMLCatalog extends DataType
     //-- Fields ----------------------------------------------------------------
 
     /** Holds dtd/entity objects until needed. */
-    private Vector<ResourceLocation> elements = new Vector<ResourceLocation>();
+    private Vector<ResourceLocation> elements = new Vector<>();
 
     /**
      * Classpath in which to attempt to resolve resources.
@@ -435,7 +435,7 @@ public class XMLCatalog extends DataType
                 } else {
                     baseURL = new URL(base);
                 }
-                URL url = (uri.length() == 0 ? baseURL : new URL(baseURL, uri));
+                URL url = uri.isEmpty() ? baseURL : new URL(baseURL, uri);
                 source.setInputSource(new InputSource(url.toString()));
             } catch (MalformedURLException ex) {
                 // At this point we are probably in failure mode, but
@@ -474,7 +474,7 @@ public class XMLCatalog extends DataType
         if (!isReference()) {
             return this;
         }
-        return getCheckedRef(XMLCatalog.class, "xmlcatalog");
+        return getCheckedRef(XMLCatalog.class);
     }
 
     /**
@@ -555,10 +555,10 @@ public class XMLCatalog extends DataType
      * inherit the EntityResolver of the original (although arguably
      * it should).  See below:</p>
      *
-     * <tt>"If an application wants to set the ErrorHandler or
+     * <code>"If an application wants to set the ErrorHandler or
      * EntityResolver for an XMLReader used during a transformation,
      * it should use a URIResolver to return the SAXSource which
-     * provides (with getXMLReader) a reference to the XMLReader"</tt>
+     * provides (with getXMLReader) a reference to the XMLReader"</code>
      *
      * <p>...quoted from page 118 of the Java API for XML
      * Processing 1.1 specification</p>
@@ -572,9 +572,7 @@ public class XMLCatalog extends DataType
             spFactory.setNamespaceAware(true);
             try {
                 reader = spFactory.newSAXParser().getXMLReader();
-            } catch (ParserConfigurationException ex) {
-                throw new TransformerException(ex);
-            } catch (SAXException ex) {
+            } catch (ParserConfigurationException | SAXException ex) {
                 throw new TransformerException(ex);
             }
         }
@@ -922,21 +920,17 @@ public class XMLCatalog extends DataType
             // in the classpath.
             //
             try {
-                setXMLCatalog =
-                    resolverImplClass.getMethod("setXMLCatalog",
-                                                new Class[] {XMLCatalog.class});
+                setXMLCatalog = resolverImplClass.getMethod("setXMLCatalog",
+                        XMLCatalog.class);
 
-                parseCatalog =
-                    resolverImplClass.getMethod("parseCatalog",
-                                                new Class[] {String.class});
+                parseCatalog = resolverImplClass.getMethod("parseCatalog",
+                        String.class);
 
-                resolveEntity =
-                    resolverImplClass.getMethod("resolveEntity",
-                                                new Class[] {String.class, String.class});
+                resolveEntity = resolverImplClass.getMethod("resolveEntity",
+                        String.class, String.class);
 
-                resolve =
-                    resolverImplClass.getMethod("resolve",
-                                                new Class[] {String.class, String.class});
+                resolve = resolverImplClass.getMethod("resolve",
+                        String.class, String.class);
             } catch (NoSuchMethodException ex) {
                 throw new BuildException(ex);
             }
@@ -986,9 +980,8 @@ public class XMLCatalog extends DataType
                 // this possibility.
                 //
                 try {
-                    result =
-                        (InputSource) resolveEntity.invoke(resolverImpl,
-                                                          new Object[] {publicId, systemId});
+                    result = (InputSource) resolveEntity.invoke(resolverImpl,
+                            new Object[] {publicId, systemId});
                 } catch (Exception ex) {
                     throw new BuildException(ex);
                 }
@@ -1050,9 +1043,8 @@ public class XMLCatalog extends DataType
                     result = new SAXSource(source);
                 } else {
                     try {
-                        result =
-                            (SAXSource) resolve.invoke(resolverImpl,
-                                                      new Object[] {href, base});
+                        result = (SAXSource) resolve.invoke(resolverImpl,
+                                new Object[] {href, base});
                     } catch (Exception ex) {
                         throw new BuildException(ex);
                     }
@@ -1074,9 +1066,8 @@ public class XMLCatalog extends DataType
                     }
                 }
                 try {
-                    result =
-                        (SAXSource) resolve.invoke(resolverImpl,
-                                                  new Object[] {href, base});
+                    result = (SAXSource) resolve.invoke(resolverImpl,
+                            new Object[] {href, base});
                 } catch (Exception ex) {
                     throw new BuildException(ex);
                 }
@@ -1096,8 +1087,7 @@ public class XMLCatalog extends DataType
             if (!externalCatalogsProcessed) {
 
                 try {
-                    setXMLCatalog.invoke(resolverImpl,
-                                         new Object[] {XMLCatalog.this});
+                    setXMLCatalog.invoke(resolverImpl, XMLCatalog.this);
                 } catch (Exception ex) {
                     throw new BuildException(ex);
                 }
@@ -1107,14 +1097,12 @@ public class XMLCatalog extends DataType
                 if (catPath != null) {
                     log("Using catalogpath '" + getCatalogPath() + "'",
                         Project.MSG_DEBUG);
-                    String[] catPathList = getCatalogPath().list();
 
-                    for (int i = 0; i < catPathList.length; i++) {
-                        File catFile = new File(catPathList[i]);
+                    for (String catFileName : getCatalogPath().list()) {
+                        File catFile = new File(catFileName);
                         log("Parsing " + catFile, Project.MSG_DEBUG);
                         try {
-                            parseCatalog.invoke(resolverImpl,
-                                    new Object[] {catFile.getPath()});
+                            parseCatalog.invoke(resolverImpl, catFile.getPath());
                         } catch (Exception ex) {
                             throw new BuildException(ex);
                         }
