@@ -89,7 +89,7 @@ public abstract class AbstractResourceCollectionWrapper
     @Override
     public final synchronized Iterator<Resource> iterator() {
         if (isReference()) {
-            return ((AbstractResourceCollectionWrapper) getCheckedRef()).iterator();
+            return getRef().iterator();
         }
         dieOnCircularReference();
         return new FailFast(this, createIterator());
@@ -112,7 +112,7 @@ public abstract class AbstractResourceCollectionWrapper
     @Override
     public synchronized int size() {
         if (isReference()) {
-            return ((AbstractResourceCollectionWrapper) getCheckedRef()).size();
+            return getRef().size();
         }
         dieOnCircularReference();
         return getSize();
@@ -132,7 +132,7 @@ public abstract class AbstractResourceCollectionWrapper
      */
     public synchronized boolean isFilesystemOnly() {
         if (isReference()) {
-            return ((BaseResourceCollectionContainer) getCheckedRef()).isFilesystemOnly();
+            return getRef().isFilesystemOnly();
         }
         dieOnCircularReference();
 
@@ -191,7 +191,7 @@ public abstract class AbstractResourceCollectionWrapper
     @Override
     public synchronized String toString() {
         if (isReference()) {
-            return getCheckedRef().toString();
+            return getRef().toString();
         }
         if (isEmpty()) {
             return "";
@@ -200,6 +200,10 @@ public abstract class AbstractResourceCollectionWrapper
             .collect(Collectors.joining(File.pathSeparator));
     }
 
+    private AbstractResourceCollectionWrapper getRef() {
+        return getCheckedRef(AbstractResourceCollectionWrapper.class);
+    }
+
     private BuildException oneNested() {
         return new BuildException(super.toString() + ONE_NESTED_MESSAGE);
     }
