@@ -110,6 +110,7 @@ public class URLResource extends Resource implements URLProvider {
     /**
      * Base URL which combined with the relativePath attribute defines
      * the URL.
+     * @param base URL
      * @since Ant 1.8.0
      */
     public synchronized void setBaseURL(URL base) {
@@ -123,6 +124,7 @@ public class URLResource extends Resource implements URLProvider {
     /**
      * Relative path which combined with the baseURL attribute defines
      * the URL.
+     * @param r String
      * @since Ant 1.8.0
      */
     public synchronized void setRelativePath(String r) {
@@ -141,7 +143,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized URL getURL() {
         if (isReference()) {
-            return ((URLResource) getCheckedRef()).getURL();
+            return getRef().getURL();
         }
         if (url == null) {
             if (baseURL != null) {
@@ -178,10 +180,10 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized String getName() {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).getName();
+            return getRef().getName();
         }
         String name = getURL().getFile();
-        return "".equals(name) ? name : name.substring(1);
+        return name.isEmpty() ? name : name.substring(1);
     }
 
     /**
@@ -190,7 +192,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized String toString() {
         return isReference()
-            ? getCheckedRef().toString() : String.valueOf(getURL());
+            ? getRef().toString() : String.valueOf(getURL());
     }
 
     /**
@@ -199,7 +201,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized boolean isExists() {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).isExists();
+            return getRef().isExists();
         }
         return isExists(false);
     }
@@ -260,16 +262,12 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized long getLastModified() {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).getLastModified();
+            return getRef().getLastModified();
         }
         if (!isExists(false)) {
             return UNKNOWN_DATETIME;
         }
-        return withConnection(new ConnectionUser() {
-                public long useConnection(URLConnection c) {
-                    return conn.getLastModified();
-                }
-            }, UNKNOWN_DATETIME);
+        return withConnection(c -> conn.getLastModified(), UNKNOWN_DATETIME);
     }
 
     /**
@@ -278,7 +276,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized boolean isDirectory() {
         return isReference()
-            ? ((Resource) getCheckedRef()).isDirectory()
+            ? getRef().isDirectory()
             : getName().endsWith("/");
     }
 
@@ -289,16 +287,12 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized long getSize() {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).getSize();
+            return getRef().getSize();
         }
         if (!isExists(false)) {
             return 0L;
         }
-        return withConnection(new ConnectionUser() {
-                public long useConnection(URLConnection c) {
-                    return conn.getContentLength();
-                }
-            }, UNKNOWN_SIZE);
+        return withConnection(c -> conn.getContentLength(), UNKNOWN_SIZE);
     }
 
     /**
@@ -311,15 +305,15 @@ public class URLResource extends Resource implements URLProvider {
             return true;
         }
         if (isReference()) {
-            return getCheckedRef().equals(another);
+            return getRef().equals(another);
         }
-        if (another == null || !(another.getClass().equals(getClass()))) {
+        if (another == null || another.getClass() != getClass()) {
             return false;
         }
-        URLResource otheru = (URLResource) another;
+        URLResource other = (URLResource) another;
         return getURL() == null
-            ? otheru.getURL() == null
-            : getURL().equals(otheru.getURL());
+            ? other.getURL() == null
+            : getURL().equals(other.getURL());
     }
 
     /**
@@ -328,7 +322,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized int hashCode() {
         if (isReference()) {
-            return getCheckedRef().hashCode();
+            return getRef().hashCode();
         }
         return MAGIC * ((getURL() == null) ? NULL_URL : getURL().hashCode());
     }
@@ -343,7 +337,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized InputStream getInputStream() throws IOException {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).getInputStream();
+            return getRef().getInputStream();
         }
         connect();
         try {
@@ -364,7 +358,7 @@ public class URLResource extends Resource implements URLProvider {
      */
     public synchronized OutputStream getOutputStream() throws IOException {
         if (isReference()) {
-            return ((Resource) getCheckedRef()).getOutputStream();
+            return getRef().getOutputStream();
         }
         connect();
         try {
@@ -407,6 +401,11 @@ public class URLResource extends Resource implements URLProvider {
         }
     }
 
+    @Override
+    protected URLResource getRef() {
+        return getCheckedRef(URLResource.class);
+    }
+
     /**
      * Closes the URL connection if:
      * - it is opened (i.e. the field conn is not null)
