@@ -105,7 +105,7 @@ public class ZipResource extends ArchiveResource {
      */
     public String getEncoding() {
         return isReference()
-            ? ((ZipResource) getCheckedRef()).getEncoding() : encoding;
+            ? getRef().getEncoding() : encoding;
     }
 
     /**
@@ -127,28 +127,9 @@ public class ZipResource extends ArchiveResource {
      */
     public InputStream getInputStream() throws IOException {
         if (isReference()) {
-            return getCheckedRef().getInputStream();
+            return getRef().getInputStream();
         }
-        final ZipFile z = new ZipFile(getZipfile(), getEncoding());
-        ZipEntry ze = z.getEntry(getName());
-        if (ze == null) {
-            z.close();
-            throw new BuildException("no entry " + getName() + " in "
-                                     + getArchive());
-        }
-        return new FilterInputStream(z.getInputStream(ze)) {
-            public void close() throws IOException {
-                FileUtils.close(in);
-                z.close();
-            }
-            protected void finalize() throws Throwable {
-                try {
-                    close();
-                } finally {
-                    super.finalize();
-                }
-            }
-        };
+        return getZipEntryStream(new ZipFile(getZipfile(), getEncoding()), getName());
     }
 
     /**
@@ -161,7 +142,7 @@ public class ZipResource extends ArchiveResource {
      */
     public OutputStream getOutputStream() throws IOException {
         if (isReference()) {
-            return getCheckedRef().getOutputStream();
+            return getRef().getOutputStream();
         }
         throw new UnsupportedOperationException(
             "Use the zip task for zip output.");
@@ -174,7 +155,7 @@ public class ZipResource extends ArchiveResource {
      */
     public ZipExtraField[] getExtraFields() {
         if (isReference()) {
-            return ((ZipResource) getCheckedRef()).getExtraFields();
+            return getRef().getExtraFields();
         }
         checkEntry();
         if (extras == null) {
@@ -192,6 +173,36 @@ public class ZipResource extends ArchiveResource {
         return method;
     }
 
+    /**
+     * Return an InputStream for reading the contents of a ZipEntry
+     * with autoclose.
+     * @param zipFile a org.apache.tools.zip.ZipFile
+     * @param zipEntry String a name of a zip entry
+     * @return an InputStream object
+     * @throws IOException if the entry cannot be read
+     */
+    public static InputStream getZipEntryStream(ZipFile zipFile,
+                                                String zipEntry) throws IOException {
+        ZipEntry ze = zipFile.getEntry(zipEntry);
+        if (ze == null) {
+            zipFile.close();
+            throw new BuildException("no entry " + zipEntry + " in " + zipFile.getName());
+        }
+        return new FilterInputStream(zipFile.getInputStream(ze)) {
+            public void close() throws IOException {
+                FileUtils.close(in);
+                zipFile.close();
+            }
+            protected void finalize() throws Throwable {
+                try {
+                    close();
+                } finally {
+                    super.finalize();
+                }
+            }
+        };
+    }
+
     /**
      * fetches information from the named entry inside the archive.
      */
@@ -208,6 +219,11 @@ public class ZipResource extends ArchiveResource {
         }
     }
 
+    @Override
+    protected ZipResource getRef() {
+        return getCheckedRef(ZipResource.class);
+    }
+
     private void setEntry(ZipEntry e) {
         if (e == null) {
             setExists(false);
