@@ -50,7 +50,7 @@ public abstract class AbstractSelectorContainer extends DataType
     @Override
     public boolean hasSelectors() {
         if (isReference()) {
-            return getCheckedRef().hasSelectors();
+            return getRef().hasSelectors();
         }
         dieOnCircularReference();
         return !selectorsList.isEmpty();
@@ -62,7 +62,7 @@ public abstract class AbstractSelectorContainer extends DataType
      */
     public int selectorCount() {
         if (isReference()) {
-            return getCheckedRef().selectorCount();
+            return getRef().selectorCount();
         }
         dieOnCircularReference();
         return selectorsList.size();
@@ -75,8 +75,7 @@ public abstract class AbstractSelectorContainer extends DataType
      */
     public FileSelector[] getSelectors(Project p) {
         if (isReference()) {
-            return getCheckedRef(AbstractSelectorContainer.class,
-                getDataTypeName(), p).getSelectors(p);
+            return getRef(p).getSelectors(p);
         }
         dieOnCircularReference(p);
         return selectorsList.toArray(new FileSelector[selectorsList.size()]);
@@ -88,7 +87,7 @@ public abstract class AbstractSelectorContainer extends DataType
      */
     public Enumeration<FileSelector> selectorElements() {
         if (isReference()) {
-            return getCheckedRef().selectorElements();
+            return getRef().selectorElements();
         }
         dieOnCircularReference();
         return Collections.enumeration(selectorsList);
@@ -137,7 +136,7 @@ public abstract class AbstractSelectorContainer extends DataType
      */
     public void validate() {
         if (isReference()) {
-            getCheckedRef().validate();
+            getRef().validate();
         }
         dieOnCircularReference();
         selectorsList.stream().filter(BaseSelector.class::isInstance)
@@ -324,6 +323,22 @@ public abstract class AbstractSelectorContainer extends DataType
         appendSelector(o);
     }
 
+    /**
+     * @param o PosixGroupSelector
+     * @since 1.10.4
+     */
+    public void addPosixGroup(PosixGroupSelector o) {
+        appendSelector(o);
+    }
+
+    /**
+     * @param o PosixPermissionsSelector
+     * @since 1.10.4
+     */
+    public void addPosixPermissions(PosixPermissionsSelector o) {
+        appendSelector(o);
+    }
+
     /**
      * add an arbitrary selector
      * @param selector the selector to add
@@ -349,9 +364,13 @@ public abstract class AbstractSelectorContainer extends DataType
         }
     }
 
+    /**
+     * Clone the selector container.
+     * @return a deep clone of a selector container.
+     */
     public synchronized Object clone() {
         if (isReference()) {
-            return ((AbstractSelectorContainer) getCheckedRef()).clone();
+            return getRef().clone();
         }
         try {
             AbstractSelectorContainer sc =
@@ -363,9 +382,13 @@ public abstract class AbstractSelectorContainer extends DataType
         }
     }
 
-    @Override
-    protected AbstractSelectorContainer getCheckedRef() {
-        return (AbstractSelectorContainer) super.getCheckedRef();
+
+    private AbstractSelectorContainer getRef(Project p) {
+        return getCheckedRef(AbstractSelectorContainer.class, getDataTypeName(), p);
+    }
+
+    private AbstractSelectorContainer getRef() {
+        return getCheckedRef(AbstractSelectorContainer.class);
     }
 
 }
