@@ -20,9 +20,9 @@ package org.apache.tools.ant.taskdefs;
 
 import java.io.BufferedInputStream;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.nio.file.Files;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildFileRule;
@@ -144,8 +144,8 @@ public class ReplaceTest {
     public void assertEqualContent(File expect, File result) throws IOException {
         assertTrue("Expected file " + result + " doesn't exist", result.exists());
 
-        try (InputStream inExpect = new BufferedInputStream(new FileInputStream(expect));
-             InputStream inResult = new BufferedInputStream(new FileInputStream(result))) {
+        try (InputStream inExpect = new BufferedInputStream(Files.newInputStream(expect.toPath()));
+             InputStream inResult = new BufferedInputStream(Files.newInputStream(result.toPath()))) {
             int expectedByte = inExpect.read();
             while (expectedByte != -1) {
                 assertEquals(expectedByte, inResult.read());
