@@ -19,9 +19,11 @@
 package org.apache.tools.ant.types;
 
 import java.io.File;
+import java.nio.file.Paths;
 import java.util.Locale;
 
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.MagicTestNames;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.condition.Os;
 import org.junit.Before;
@@ -31,6 +33,7 @@ import org.junit.rules.ExpectedException;
 
 import static org.hamcrest.Matchers.endsWith;
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertThat;
 
 /**
@@ -52,8 +55,8 @@ public class PathTest {
     @Before
     public void setUp() {
         project = new Project();
-        if (System.getProperty("root") != null) {
-            project.setBasedir(System.getProperty("root"));
+        if (System.getProperty(MagicTestNames.TEST_ROOT_DIRECTORY) != null) {
+            project.setBasedir(System.getProperty(MagicTestNames.TEST_ROOT_DIRECTORY));
         }
         p = new Path(project);
     }
@@ -572,11 +575,15 @@ public class PathTest {
         DirSet d = new DirSet();
         d.setProject(project);
         d.setDir(project.resolveFile("."));
-        d.setIncludes("build");
+        String s = System.getProperty("build.tests.value");
+        assertNotNull("build.tests.value not set", s);
+        String n = Paths.get(s).getParent().getFileName().toString().equals("ant")
+                ? "target" : "build";
+        d.setIncludes(n);
         p.addDirset(d);
         String[] l = p.list();
         assertEquals(1, l.length);
-        assertEquals(project.resolveFile("build").getAbsolutePath(), l[0]);
+        assertEquals(project.resolveFile(n).getAbsolutePath(), l[0]);
     }
 
     @Test
